@@ -1,3 +1,14 @@
+googleKmlDependency <- function() {
+  list(
+    htmltools::htmlDependency(
+      "kml",
+      "1.0.0",
+      system.file("htmlwidgets/lib/kml", package = "googleway"),
+      script = c("kml.js")
+    )
+  )
+}
+
 #' Add KML
 #'
 #' Adds a KML layer to a map.
@@ -32,6 +43,8 @@ add_kml <- function(map, kml_url, layer_id = NULL){
 
   kml <- jsonlite::toJSON(data.frame(url = kml_url))
 
+  map <- addDependency(map, googleKmlDependency())
+
   invoke_method(map, 'add_kml', kml, layer_id)
 }
 
